asr.infraredpolarizability
==========================

.. automodule:: asr.infraredpolarizability

   
   
   .. rubric:: Functions

   
   .. autofunction:: create_plot
   .. autofunction:: get_phonon_pol
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   